from ._cli import steinbock_cmd_group


if __name__ == "__main__":
    steinbock_cmd_group(prog_name="steinbock")
